@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::Plugin::PromptIfStale;
 {
-  $Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.013';
+  $Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.014';
 }
-# git description: v0.012-TRIAL-4-ga5088ea
+# git description: v0.013-5-g72f2ebb
 
 BEGIN {
   $Dist::Zilla::Plugin::PromptIfStale::AUTHORITY = 'cpan:ETHER';
@@ -18,7 +18,7 @@ with 'Dist::Zilla::Role::BeforeBuild',
 
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose qw(ArrayRef Bool Str);
-use List::MoreUtils 'uniq';
+use List::MoreUtils qw(uniq none);
 use version;
 use Path::Tiny;
 use Cwd;
@@ -29,7 +29,7 @@ use Module::Path 'module_path';
 use Module::Metadata;
 use namespace::autoclean;
 
-sub mvp_multivalue_args { 'modules' }
+sub mvp_multivalue_args { qw(modules skip) }
 sub mvp_aliases { {
     module => 'modules',
     check_all => 'check_all_plugins',
@@ -59,6 +59,27 @@ has check_all_prereqs => (
     default => 0,
 );
 
+has skip => (
+    isa => ArrayRef[Str],
+    traits => [ 'Array' ],
+    handles => { skip => 'elements' },
+    lazy => 1,
+    default => sub { [] },
+);
+
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    $config->{'' . __PACKAGE__} = {
+        (map { $_ => ($self->$_ || 0) } qw(phase check_all_plugins check_all_prereqs)),
+        (map { $_ => [ $self->$_ ] } qw(modules skip)),
+    };
+
+    return $config;
+};
+
 sub before_build
 {
     my $self = shift;
@@ -178,11 +199,14 @@ has _modules_before_build => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        return [ uniq
-            $self->modules,
-            $self->check_all_plugins
-                ? map { blessed $_ } @{ $self->zilla->plugins }
-                : (),
+        my @skip = $self->skip;
+        return [
+            grep { my $module = $_; none { $module eq $_ } @skip }
+            uniq
+                $self->modules,
+                $self->check_all_plugins
+                    ? map { blessed $_ } @{ $self->zilla->plugins }
+                    : ()
         ];
     },
 );
@@ -195,7 +219,9 @@ has _modules_prereq => (
     default => sub {
         my $self = shift;
         my $prereqs = $self->zilla->prereqs->as_string_hash;
+        my @skip = $self->skip;
         [
+            grep { my $module = $_; none { $module eq $_ } @skip }
             map { keys %$_ }
             grep { defined }
             map { @{$_}{qw(requires recommends suggests)} }
@@ -278,7 +304,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -331,6 +357,10 @@ distribution metadata should be checked. The modules are a merged list taken
 from the C<configure>, C<build>, C<runtime>, C<test> and C<develop> phases,
 and the C<requires>, C<recommends> and C<suggests> types.
 
+=item * C<skip>
+
+The name of a module to exempt from checking. Can be provided more than once.
+
 =back
 
 =for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release
